# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: lofar_sid/interface/stationcontrol/subrack.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'lofar_sid/interface/stationcontrol/subrack.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0lofar_sid/interface/stationcontrol/subrack.proto\"\'\n\x11SubrackIdentifier\x12\x12\n\nsubrack_id\x18\x01 \x01(\t\"h\n\x11SetSubrackRequest\x12&\n\nidentifier\x18\x01 \x01(\x0b\x32\x12.SubrackIdentifier\x12+\n\x0cpower_status\x18\x02 \x01(\x0e\x32\x15.Subrack_Power_Status\";\n\x11GetSubrackRequest\x12&\n\nidentifier\x18\x01 \x01(\x0b\x32\x12.SubrackIdentifier\"d\n\rSubrackResult\x12&\n\nidentifier\x18\x01 \x01(\x0b\x32\x12.SubrackIdentifier\x12+\n\x0cpower_status\x18\x02 \x01(\x0e\x32\x15.Subrack_Power_Status\"R\n\x0cSubrackReply\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x11\n\texception\x18\x02 \x01(\t\x12\x1e\n\x06result\x18\x03 \x01(\x0b\x32\x0e.SubrackResult*C\n\x14Subrack_Power_Status\x12\x15\n\x11Subrack_POWER_OFF\x10\x00\x12\x14\n\x10Subrack_POWER_ON\x10\x01\x32y\n\x07Subrack\x12\x36\n\x0fGetSubrackPower\x12\x12.GetSubrackRequest\x1a\r.SubrackReply\"\x00\x12\x36\n\x0fSetSubrackPower\x12\x12.SetSubrackRequest\x1a\r.SubrackReply\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'lofar_sid.interface.stationcontrol.subrack_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SUBRACK_POWER_STATUS']._serialized_start=446
  _globals['_SUBRACK_POWER_STATUS']._serialized_end=513
  _globals['_SUBRACKIDENTIFIER']._serialized_start=52
  _globals['_SUBRACKIDENTIFIER']._serialized_end=91
  _globals['_SETSUBRACKREQUEST']._serialized_start=93
  _globals['_SETSUBRACKREQUEST']._serialized_end=197
  _globals['_GETSUBRACKREQUEST']._serialized_start=199
  _globals['_GETSUBRACKREQUEST']._serialized_end=258
  _globals['_SUBRACKRESULT']._serialized_start=260
  _globals['_SUBRACKRESULT']._serialized_end=360
  _globals['_SUBRACKREPLY']._serialized_start=362
  _globals['_SUBRACKREPLY']._serialized_end=444
  _globals['_SUBRACK']._serialized_start=515
  _globals['_SUBRACK']._serialized_end=636
# @@protoc_insertion_point(module_scope)
